==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMDelaySpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class JVMDelaySpecFluentImpl<A extends JVMDelaySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements JVMDelaySpecFluent<A> {

    private Boolean after;
    private String classname;
    private String methodname;
    private Integer offset;
    private Integer time;

    public JVMDelaySpecFluentImpl() {
    }

    public JVMDelaySpecFluentImpl(JVMDelaySpec instance) {
        this.withAfter(instance.getAfter()); 
        this.withClassname(instance.getClassname()); 
        this.withMethodname(instance.getMethodname()); 
        this.withOffset(instance.getOffset()); 
        this.withTime(instance.getTime()); 
    }

    public Boolean isAfter() {
        return this.after;
    }

    public A withAfter(Boolean after) {
        this.after=after; return (A) this;
    }

    public Boolean hasAfter() {
        return this.after != null;
    }

    public A withNewAfter(String arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public A withNewAfter(boolean arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public String getClassname() {
        return this.classname;
    }

    public A withClassname(String classname) {
        this.classname=classname; return (A) this;
    }

    public Boolean hasClassname() {
        return this.classname != null;
    }

    public A withNewClassname(String arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuilder arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuffer arg1) {
        return (A)withClassname(new String(arg1));
    }

    public String getMethodname() {
        return this.methodname;
    }

    public A withMethodname(String methodname) {
        this.methodname=methodname; return (A) this;
    }

    public Boolean hasMethodname() {
        return this.methodname != null;
    }

    public A withNewMethodname(String arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuilder arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuffer arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public Integer getOffset() {
        return this.offset;
    }

    public A withOffset(Integer offset) {
        this.offset=offset; return (A) this;
    }

    public Boolean hasOffset() {
        return this.offset != null;
    }

    public A withNewOffset(String arg1) {
        return (A)withOffset(new Integer(arg1));
    }

    public A withNewOffset(int arg1) {
        return (A)withOffset(new Integer(arg1));
    }

    public Integer getTime() {
        return this.time;
    }

    public A withTime(Integer time) {
        this.time=time; return (A) this;
    }

    public Boolean hasTime() {
        return this.time != null;
    }

    public A withNewTime(String arg1) {
        return (A)withTime(new Integer(arg1));
    }

    public A withNewTime(int arg1) {
        return (A)withTime(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        JVMDelaySpecFluentImpl that = (JVMDelaySpecFluentImpl) o;
        if (after != null ? !after.equals(that.after) :that.after != null) return false;
        if (classname != null ? !classname.equals(that.classname) :that.classname != null) return false;
        if (methodname != null ? !methodname.equals(that.methodname) :that.methodname != null) return false;
        if (offset != null ? !offset.equals(that.offset) :that.offset != null) return false;
        if (time != null ? !time.equals(that.time) :that.time != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(after,  classname,  methodname,  offset,  time,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMDelaySpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class JVMDelaySpecFluentImpl<A extends JVMDelaySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements JVMDelaySpecFluent<A> {

    private Boolean after;
    private String classname;
    private String methodname;
    private Integer offset;
    private Integer time;

    public JVMDelaySpecFluentImpl() {
    }

    public JVMDelaySpecFluentImpl(JVMDelaySpec instance) {
        this.withAfter(instance.getAfter()); 
        this.withClassname(instance.getClassname()); 
        this.withMethodname(instance.getMethodname()); 
        this.withOffset(instance.getOffset()); 
        this.withTime(instance.getTime()); 
    }

    public Boolean getAfter() {
        return this.after;
    }

    public A withAfter(Boolean after) {
        this.after=after; return (A) this;
    }

    public Boolean hasAfter() {
        return this.after != null;
    }

    public A withNewAfter(String arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public A withNewAfter(boolean arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public String getClassname() {
        return this.classname;
    }

    public A withClassname(String classname) {
        this.classname=classname; return (A) this;
    }

    public Boolean hasClassname() {
        return this.classname != null;
    }

    public A withNewClassname(StringBuilder arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(int[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(char[] arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuffer arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(byte[] arg1,int arg2) {
        return (A)withClassname(new String(arg1, arg2));
    }

    public A withNewClassname(byte[] arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(char[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(byte[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withClassname(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewClassname(String arg1) {
        return (A)withClassname(new String(arg1));
    }

    public String getMethodname() {
        return this.methodname;
    }

    public A withMethodname(String methodname) {
        this.methodname=methodname; return (A) this;
    }

    public Boolean hasMethodname() {
        return this.methodname != null;
    }

    public A withNewMethodname(StringBuilder arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(int[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(char[] arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuffer arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(byte[] arg1,int arg2) {
        return (A)withMethodname(new String(arg1, arg2));
    }

    public A withNewMethodname(byte[] arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(char[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(byte[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMethodname(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMethodname(String arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public Integer getOffset() {
        return this.offset;
    }

    public A withOffset(Integer offset) {
        this.offset=offset; return (A) this;
    }

    public Boolean hasOffset() {
        return this.offset != null;
    }

    public A withNewOffset(int arg1) {
        return (A)withOffset(new Integer(arg1));
    }

    public Integer getTime() {
        return this.time;
    }

    public A withTime(Integer time) {
        this.time=time; return (A) this;
    }

    public Boolean hasTime() {
        return this.time != null;
    }

    public A withNewTime(int arg1) {
        return (A)withTime(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        JVMDelaySpecFluentImpl that = (JVMDelaySpecFluentImpl) o;
        if (after != null ? !after.equals(that.after) :that.after != null) return false;
        if (classname != null ? !classname.equals(that.classname) :that.classname != null) return false;
        if (methodname != null ? !methodname.equals(that.methodname) :that.methodname != null) return false;
        if (offset != null ? !offset.equals(that.offset) :that.offset != null) return false;
        if (time != null ? !time.equals(that.time) :that.time != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(after,  classname,  methodname,  offset,  time,  super.hashCode());
    }

}
